[![tests](https://github.com/vedad/olio/actions/workflows/tests.yml/badge.svg)](https://github.com/vedad/ell/actions/workflows/tests.yml)

# olio
Surface velocity maps of limb darkened stars, commonly used modelling the
Rossiter-McLaughlin effect of transiting exoplanets with _Doppler shadow_
techniques.
